==> zendesk_forms-8.x-1.0.tar.gz: zendesk_forms/src/Plugin/Block/ZendeskFormBlock.php <==
<?php

namespace Drupal\zendesk_forms\Plugin\Block;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormBuilderInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\zendesk_forms\Form\ZendeskSupportForm;
use Drupal\Core\Url;

/**
 * Provides a block for the Zendesk Support Form.
 *
 * @Block(
 *   id = "zendesk_form_block",
 *   admin_label = @Translation("Zendesk Form"),
 *   category = @Translation("Zendesk Forms"),
 * )
 */
class ZendeskFormBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * The form builder service.
   *
   * @var \Drupal\Core\Form\FormBuilderInterface
   */
  protected $formBuilder;

  /**
   * Creates a ZendeskForm instance.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Form\FormBuilderInterface $form_builder
   *   The form builder service.
   */
  public function __construct(
    array $configuration,
    $plugin_id,
    $plugin_definition,
    FormBuilderInterface $form_builder
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->formBuilder = $form_builder;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('form_builder')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    return $this->formBuilder->getForm(ZendeskSupportForm::class);
  }

  /**
   * {@inheritdoc}
   */
  protected function blockAccess(AccountInterface $account) {
    $config = \Drupal::config('zendesk_forms.settings');

    if (!($config->get('user_name') && $config->get('api_token') && $config->get('subdomain'))) {
      if ($account->hasPermission('administer zendesk_forms')) {
        $messenger = \Drupal::messenger();
        $url = Url::fromRoute('zendesk_forms.settings');
        $messenger->addMessage(t('Zendesk credentials are not entered. Please enter them <a href=":url">here</a>.', [':url' => $url->toString()]));
      }
      return AccessResult::forbidden();
    }

    return AccessResult::allowedIfHasPermission($account, 'access content');
  }

}

==> zendesk_forms-8.x-1.2.tar.gz: zendesk_forms/src/Plugin/Block/ZendeskFormBlock.php <==
<?php

namespace Drupal\zendesk_forms\Plugin\Block;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormBuilderInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Messenger\MessengerInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\zendesk_forms\Form\ZendeskSupportForm;
use Drupal\Core\Url;

/**
 * Provides a block for the Zendesk Support Form.
 *
 * @Block(
 *   id = "zendesk_form_block",
 *   admin_label = @Translation("Zendesk Form"),
 *   category = @Translation("Zendesk Forms"),
 * )
 */
class ZendeskFormBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * The form builder service.
   *
   * @var \Drupal\Core\Form\FormBuilderInterface
   */
  protected $formBuilder;

  /**
   * The config factory service.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface;
   */
  protected $configFactory;

  /**
   * The Messenger service.
   *
   * @var \Drupal\Core\Messenger\MessengerInterface
   */
  protected $messenger;

  /**
   * Creates a ZendeskForm instance.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Form\FormBuilderInterface $form_builder
   *   The form builder service.
   */
  public function __construct(
    array $configuration,
    $plugin_id,
    $plugin_definition,
    ConfigFactoryInterface $config_factory,
    MessengerInterface $messenger,
    FormBuilderInterface $form_builder
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->formBuilder = $form_builder;
    $this->configFactory = $config_factory;
    $this->messenger = $messenger;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('config.factory'),
      $container->get('messenger'),
      $container->get('form_builder')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    return $this->formBuilder->getForm(ZendeskSupportForm::class);
  }

  /**
   * {@inheritdoc}
   */
  protected function blockAccess(AccountInterface $account) {
    $config = $this->configFactory->get('zendesk_forms.settings');

    if (!($config->get('user_name') && $config->get('api_token') && $config->get('subdomain'))) {
      if ($account->hasPermission('administer zendesk_forms')) {
        $url = Url::fromRoute('zendesk_forms.settings');
        $this->messenger->addMessage(t('Zendesk credentials are not entered. Please enter them <a href=":url">here</a>.', [':url' => $url->toString()]));
      }
      return AccessResult::forbidden();
    }

    return AccessResult::allowedIfHasPermission($account, 'access content');
  }

}
